from abqpy.decorators import abaqus_class_doc


@abaqus_class_doc
class OdbModelFieldVarList:
    """The read-only OdbModelFieldVarList object lists all variables available for the model in
    the current OdbDisplay object.

    .. note::
        This object can be accessed by::

            import visualization
            session.viewports[name].layers[name].odbDisplay.modelVariableList
            session.viewports[name].odbDisplay.modelVariableList
    """

    ...



from typing import Optional

from abqpy.decorators import abaqus_class_doc, abaqus_method_doc
from typing_extensions import Literal

from ..UtilityAndView.abaqusConstants import AXIS_3, ROTATION_NONE, SymbolicConstant
from ..UtilityAndView.abaqusConstants import abaqusConstants as C


@abaqus_class_doc
class SectionLayer:
    """The SectionLayer object defines the material layer in a composite shell.

    .. note::
        This object can be accessed by::

            import section
            mdb.models[name].parts[name].compositeLayups[i].section.layup[i]
            mdb.models[name].sections[name].layup[i]
            import odbSection
            session.odbs[name].sections[name].layup[i]

        The corresponding analysis keywords are:

        - SHELL SECTION
        - SHELL GENERAL SECTION

    .. versionchanged:: 2017
        The `thicknessType` attribute and `thicknessField` attribute were removed.
    """

    #: A Float specifying the thickness of the section layer.
    thickness: float

    #: A String specifying the name of the section layer material.
    material: str

    #: A Float or a String specifying the relative orientation of the section layer. A Float
    #: specifies the angular orientation; a String specifies a user-subroutine orientation
    #: name. If a String is specified, a user-subroutine orientation is used, otherwise the
    #: Float value is used as an angular orientation. The default value is 0.0.
    orientAngle: float = 0

    #: An Int specifying the number of integration points to be used through the section. This
    #: argument is valid only if the **preIntegrate** argument on the parent
    #: CompositeShellSection object is set to ON. The default value is 3.
    numIntPts: int = 3

    #: A SymbolicConstant specifying the axis of a cylindrical or spherical datum coordinate
    #: system about which an additional rotation is applied. For shells this axis is also the
    #: shell normal. This only applies if a valid reference is provided for the orientation.
    #: Possible values are AXIS_1, AXIS_2, and AXIS_3. The default value is AXIS_3.
    axis: SymbolicConstant = AXIS_3

    #: A Float specifying the angle of the additional rotation. This only applies if a valid
    #: reference is provided for the orientation. The default value is 0.0.
    angle: float = 0

    #: A SymbolicConstant specifying the method used to describe the additional rotation when a
    #: valid orientation is specified. Possible values are ROTATION_NONE, ROTATION_ANGLE, and
    #: ROTATION_FIELD. The default value is ROTATION_NONE.
    additionalRotationType: SymbolicConstant = ROTATION_NONE

    #: A String specifying the ply identifier for this section layer. The default value is "".
    plyName: str = ""

    #: The SymbolicConstant None or a DatumCsys object specifying a coordinate system reference
    #: for the relative orientation of this layer. If this reference is valid it is used as the
    #: relative orientation of the layer, otherwise the **orientAngle** is used as described. The
    #: default value is None.
    orientation: Optional[SymbolicConstant] = None

    #: A String specifying the name of the field specifying the additional rotation. The
    #: default value is "".
    additionalRotationField: str = ""

    @abaqus_method_doc
    def __init__(
        self,
        thickness: float,
        material: str,
        orientAngle: float = 0,
        numIntPts: int = 3,
        axis: Literal[C.AXIS_1, C.AXIS_3, C.AXIS_2] = AXIS_3,
        angle: float = 0,
        additionalRotationType: Literal[C.ROTATION_NONE, C.ROTATION_FIELD, C.ROTATION_ANGLE] = ROTATION_NONE,
        plyName: str = "",
        orientation: Optional[SymbolicConstant] = None,
        additionalRotationField: str = "",
    ):
        """This method creates a SectionLayer object.

        .. note::
            This function can be accessed by::

                section.SectionLayer
                odbSection.SectionLayer

        .. versionchanged:: 2017
            The `thicknessType` argument and `thicknessField` argument were removed.

        Parameters
        ----------
        thickness
            A Float specifying the thickness of the section layer.
        material
            A String specifying the name of the section layer material.
        orientAngle
            A Float or a String specifying the relative orientation of the section layer. A Float
            specifies the angular orientation; a String specifies a user-subroutine orientation
            name. If a String is specified, a user-subroutine orientation is used, otherwise the
            Float value is used as an angular orientation. The default value is 0.0.
        numIntPts
            An Int specifying the number of integration points to be used through the section. This
            argument is valid only if the **preIntegrate** argument on the parent
            CompositeShellSection object is set to ON. The default value is 3.
        axis
            A SymbolicConstant specifying the axis of a cylindrical or spherical datum coordinate
            system about which an additional rotation is applied. For shells this axis is also the
            shell normal. This only applies if a valid reference is provided for the orientation.
            Possible values are AXIS_1, AXIS_2, and AXIS_3. The default value is AXIS_3.
        angle
            A Float specifying the angle of the additional rotation. This only applies if a valid
            reference is provided for the orientation. The default value is 0.0.
        additionalRotationType
            A SymbolicConstant specifying the method used to describe the additional rotation when a
            valid orientation is specified. Possible values are ROTATION_NONE, ROTATION_ANGLE, and
            ROTATION_FIELD. The default value is ROTATION_NONE.
        plyName
            A String specifying the ply identifier for this section layer. The default value is "".
        orientation
            The SymbolicConstant None or a DatumCsys object specifying a coordinate system reference
            for the relative orientation of this layer. If this reference is valid it is used as the
            relative orientation of the layer, otherwise the **orientAngle** is used as described. The
            default value is None.
        additionalRotationField
            A String specifying the name of the field specifying the additional rotation. The
            default value is "".

        Returns
        -------
        SectionLayer
            A SectionLayer object.
        """
        ...



from abaqus.Job.Job import Job  # noqa # pylint: disable=unused-import
from abaqus.Odb.AnalyticSurfaceSegment import AnalyticSurfaceSegment  # noqa # pylint: disable=unused-import
from abaqus.Odb.HistoryPoint import HistoryPoint  # noqa # pylint: disable=unused-import
from odbAccess import AnalyticSurfaceProfile  # noqa # pylint: disable=unused-import
from odbAccess import Odb  # noqa # pylint: disable=unused-import
from odbAccess import isUpgradeRequiredForOdb  # noqa # pylint: disable=unused-import
from odbAccess import openOdb  # noqa # pylint: disable=unused-import
from odbAccess import upgradeOdb  # noqa # pylint: disable=unused-import
# from odbAccess import closeOdb  # noqa # pylint: disable=unused-import
# from odbAccess import truncateOdb  # noqa # pylint: disable=unused-import



from abqpy.decorators import abaqus_class_doc, abaqus_method_doc
from typing_extensions import Literal

from .Amplitude import Amplitude
from ..UtilityAndView.abaqusConstants import STEP, SymbolicConstant
from ..UtilityAndView.abaqusConstants import abaqusConstants as C


@abaqus_class_doc
class SmoothStepAmplitude(Amplitude):
    """The SmoothStepAmplitude object defines an amplitude that ramps up or down smoothly from
    one data point to another.
    The SmoothStepAmplitude object is derived from the Amplitude object.

    .. note::
        This object can be accessed by::

            import amplitude
            mdb.models[name].amplitudes[name]
            import odbAmplitude
            session.odbs[name].amplitudes[name]

        The corresponding analysis keywords are:

        - AMPLITUDE
    """

    #: A String specifying the repository key.
    name: str

    #: A sequence of pairs of Floats specifying time/frequency and amplitude pairs. Possible
    #: values for time/frequency are positive numbers.
    data: tuple

    #: A SymbolicConstant specifying the time span of the amplitude. Possible values are STEP
    #: and TOTAL. The default value is STEP.
    timeSpan: SymbolicConstant = STEP

    @abaqus_method_doc
    def __init__(self, name: str, data: tuple, timeSpan: Literal[C.STEP, C.TOTAL] = STEP):
        """This method creates a SmoothStepAmplitude object.

        .. note::
            This function can be accessed by::

                mdb.models[name].SmoothStepAmplitude
                session.odbs[name].SmoothStepAmplitude

        Parameters
        ----------
        name
            A String specifying the repository key.
        data
            A sequence of pairs of Floats specifying time/frequency and amplitude pairs. Possible
            values for time/frequency are positive numbers.
        timeSpan
            A SymbolicConstant specifying the time span of the amplitude. Possible values are STEP
            and TOTAL. The default value is STEP.

        Returns
        -------
        SmoothStepAmplitude
            A SmoothStepAmplitude object.

        Raises
        ------
        InvalidNameError
        RangeError
        """
        super().__init__()

    @abaqus_method_doc
    def setValues(self, timeSpan: Literal[C.STEP, C.TOTAL] = STEP):
        """This method modifies the SmoothStepAmplitude object.

        Parameters
        ----------
        timeSpan
            A SymbolicConstant specifying the time span of the amplitude. Possible values are STEP
            and TOTAL. The default value is STEP.

        Raises
        ------
        RangeError
        """
        ...



from abqpy.decorators import abaqus_class_doc, abaqus_method_doc


@abaqus_class_doc
class GapHeatGeneration:
    """The GapHeatGeneration object specifies heat generation for a contact interaction
    property.

    .. note::
        This object can be accessed by::

            import interaction
            mdb.models[name].interactionProperties[name].heatGeneration

        The corresponding analysis keywords are:

        - GAP HEAT GENERATION
    """

    #: A Float specifying the fraction of dissipated energy caused by friction or electric
    #: currents that is converted to heat. The default value is 1.0.
    conversionFraction: float = 1

    #: A Float specifying the fraction of converted heat distributed to the slave surface.
    #: The default value is 0.5.
    slaveFraction: float = 0

    @abaqus_method_doc
    def __init__(self, conversionFraction: float = 1, slaveFraction: float = 0):
        """This method creates a GapHeatGeneration object.

        .. note::
            This function can be accessed by::

                mdb.models[name].interactionProperties[name].HeatGeneration

        Parameters
        ----------
        conversionFraction
            A Float specifying the fraction of dissipated energy caused by friction or electric
            currents that is converted to heat. The default value is 1.0.
        slaveFraction
            A Float specifying the fraction of converted heat distributed to the slave surface.
            The default value is 0.5.

        Returns
        -------
        GapHeatGeneration
            A GapHeatGeneration object.
        """
        ...

    @abaqus_method_doc
    def setValues(self, *args, **kwargs):
        """This method modifies the GapHeatGeneration object."""
        ...



from typing import Optional

from abqpy.decorators import abaqus_function_doc

from ..Odb.Odb import Odb
from ..UtilityAndView.abaqusConstants import Boolean, SPECIFY, SymbolicConstant

"""This command writes a free body output report to a file. 

"""


@abaqus_function_doc
def writeFreeBodyReport(
    fileName: str,
    append: Boolean,
    step: Optional[int] = None,
    frame: Optional[int] = None,
    stepFrame: SymbolicConstant = SPECIFY,
    odb: Optional[Odb] = None,
):
    """This method writes a FreeBody object to a user-defined ASCII file.

    .. note::
        This function can be accessed by::

            session.writeFreeBodyReport

    Parameters
    ----------
    fileName
        A String specifying the name of the file to which the free body output will be written.
    append
        A Boolean specifying whether to append the free body output to an existing file. The
        default value is ON.
    step
        An Int identifying the step from which to obtain values. The default value is the
        current step.
    frame
        An Int identifying the frame from which to obtain values. The default value is the
        current frame.
    stepFrame
        A SymbolicConstant indicating whether to obtain the values from the specified frame or
        from all active frames. Possible values are SPECIFY and ALL. The default value is
        SPECIFY.
    odb
        An Odb object specifying the output database from which data will be read.

    Returns
    -------
    """
    ...



from typing import Optional

from abqpy.decorators import abaqus_class_doc

from .BoundaryConditionState import BoundaryConditionState
from ..UtilityAndView.abaqusConstants import SymbolicConstant


@abaqus_class_doc
class ConnVelocityBCState(BoundaryConditionState):
    """The ConnVelocityBCState object stores the propagating data for a velocity boundary
    condition in a step. One instance of this object is created internally by the
    ConnVelocityBC object for each step. The instance is also deleted internally by the
    ConnVelocityBC object.
    The ConnVelocityBCState object has no constructor or methods.
    The ConnVelocityBCState object is derived from the BoundaryConditionState object.

    .. note::
        This object can be accessed by::

            import load
            mdb.models[name].steps[name].boundaryConditionStates[name]

        The corresponding analysis keywords are:

        - CONNECTOR MOTION
    """

    #: A Float specifying the velocity component in the connector's local 1-direction.
    v1: Optional[float] = None

    #: A Float specifying the velocity component in the connector's local 2-direction.
    v2: Optional[float] = None

    #: A Float specifying the velocity component in the connector's local 3-direction.
    v3: Optional[float] = None

    #: A Float specifying the rotational velocity component in the connector's local
    #: 4-direction.
    vr1: Optional[float] = None

    #: A Float specifying the rotational velocity component in the connector's local
    #: 5-direction.
    vr2: Optional[float] = None

    #: A Float specifying the rotational velocity component in the connector's local
    #: 6-direction.
    vr3: Optional[float] = None

    #: A SymbolicConstant specifying the propagation state of the velocity component in the
    #: connector's local 1-direction. Possible values are UNSET, SET, UNCHANGED, FREED, and
    #: MODIFIED.
    v1State: Optional[SymbolicConstant] = None

    #: A SymbolicConstant specifying the propagation state of the velocity component in the
    #: connector's local 2-direction. Possible values are UNSET, SET, UNCHANGED, FREED, and
    #: MODIFIED.
    v2State: Optional[SymbolicConstant] = None

    #: A SymbolicConstant specifying the propagation state of the velocity component in the
    #: connector's local 3-direction. Possible values are UNSET, SET, UNCHANGED, FREED, and
    #: MODIFIED.
    v3State: Optional[SymbolicConstant] = None

    #: A SymbolicConstant specifying the propagation state of the rotational velocity component
    #: in the connector's local 4-direction. Possible values are UNSET, SET, UNCHANGED, FREED,
    #: and MODIFIED.
    vr1State: Optional[SymbolicConstant] = None

    #: A SymbolicConstant specifying the propagation state of the rotational velocity component
    #: in the connector's local 5-direction. Possible values are UNSET, SET, UNCHANGED, FREED,
    #: and MODIFIED.
    vr2State: Optional[SymbolicConstant] = None

    #: A SymbolicConstant specifying the propagation state of the rotational velocity component
    #: in the connector's local 6-direction. Possible values are UNSET, SET, UNCHANGED, FREED,
    #: and MODIFIED.
    vr3State: Optional[SymbolicConstant] = None

    #: A SymbolicConstant specifying the propagation state of the amplitude reference. Possible
    #: values are UNSET, SET, UNCHANGED, FREED, and MODIFIED.
    amplitudeState: Optional[SymbolicConstant] = None

    #: A SymbolicConstant specifying the propagation state of the BoundaryConditionState object. Possible values are:
    #:
    #: - NOT_YET_ACTIVE
    #: - CREATED
    #: - PROPAGATED
    #: - MODIFIED
    #: - DEACTIVATED
    #: - NO_LONGER_ACTIVE
    #: - TYPE_NOT_APPLICABLE
    #: - INSTANCE_NOT_APPLICABLE
    #: - PROPAGATED_FROM_BASE_STATE
    #: - MODIFIED_FROM_BASE_STATE
    #: - DEACTIVATED_FROM_BASE_STATE
    #: - BUILT_INTO_MODES
    status: Optional[SymbolicConstant] = None

    #: A String specifying the name of the amplitude reference. The String is empty if the
    #: boundary condition has no amplitude reference.
    amplitude: str = ""



from typing import Optional

from abqpy.decorators import abaqus_function_doc

from ..DisplayGroup.DisplayGroup import DisplayGroup
from ..Odb.Odb import Odb
from ..UtilityAndView.abaqusConstants import Boolean, SPECIFY, SymbolicConstant

"""This command writes a field output report to a file. 

"""


@abaqus_function_doc
def writeFieldReport(
    filename: str,
    append: Boolean,
    sortItem: str,
    odb: Odb,
    step: int,
    frame: int,
    outputPosition: SymbolicConstant,
    displayGroup: DisplayGroup,
    variable: SymbolicConstant,
    numericForm: Optional[SymbolicConstant] = None,
    complexAngle: Optional[float] = None,
    stepFrame: SymbolicConstant = SPECIFY,
):
    """This function writes a FieldOutput object to a user-defined ASCII file.

    .. note::
        This function can be accessed by::

            session.writeFieldReport

    Parameters
    ----------
    filename
        A String specifying the name of the file to which field output will be written.
    append
        A Boolean specifying whether to append the field output to an existing file. The default
        value is ON.
    sortItem
        A String specifying the item by which to sort the tabular values.
    odb
        An Odb object from which to obtain field output values.
    step
        An Int (or stepIndex) specifying the step from which to obtain field output values.
        Possible values are 0 ≤ **step** ≤ (*numSteps* − 1).
    frame
        An Int (or frameIndex) specifying the frame from which to obtain field output values.
        Possible values are 0 ≤ **frame** ≤ (*numFramesInStep* − 1).
    outputPosition
        A SymbolicConstant specifying the position from which to obtain data. Possible values
        are NODAL, INTEGRATION_POINT, ELEMENT_FACE, ELEMENT_NODAL, ELEMENT_CENTROID,
        WHOLE_ELEMENT, WHOLE_REGION, WHOLE_PART_INSTANCE, WHOLE_MODEL, and GENERAL_PARTICLE.
    displayGroup
        A DisplayGroup object specifying the subset of the model for which to obtain data.
    variable
        A sequence of variable description sequences specifying one or more field output
        variables for which to obtain data. Each variable description sequence contains the
        following elements:

        - **element0**: A String specifying the name of the variable.
        - **element1**: A SymbolicConstant specifying the output position at which to report data.
          Possible values are ELEMENT_CENTROID, ELEMENT_FACE, ELEMENT_NODAL, GENERAL_PARTICLE,
          INTEGRATION_POINT, NODAL, WHOLE_ELEMENT, WHOLE_MODEL, WHOLE_PART_INSTANCE, and
          WHOLE_REGION.
        - **element2**: A Sequence of tuples each consisting of a SymbolicConstant specifying the
          refinement (COMPONENT or INVARIANT), followed by a String specifying the name of a
          component or invariant for which to obtain values.
          If this element is omitted, data are written for all components and invariants (if
          applicable). This element is required if **element3** (the following element in the tuple)
          is included.
        - **element3 (if applicable)**: A Dictionary with a String key and a String value
          specifying a single section point at which to report data. The key specifies a region in
          the model; the corresponding value specifies a section point within that region. For
          example::

            {'shell < MAT > < 7 section points >': 'SPOS (fraction = 1.0)'}

          If this element is omitted, data are written for all section points (if applicable).
          If this element is omitted, data are written for all section points (if applicable).
    numericForm
        A SymbolicConstant specifying the numeric form in which to display results that contain
        complex numbers. Possible values are COMPLEX_MAGNITUDE, COMPLEX_PHASE, REAL, IMAGINARY,
        and COMPLEX_MAG_AT_ANGLE. The initial value is COMPLEX_MAGNITUDE.
    complexAngle
        A Float specifying the angle (in degrees) at which to display results that contain
        complex numbers when **numericForm** = COMPLEX_MAG_AT_ANGLE. The initial value is 0.
    stepFrame
        A SymbolicConstant indicating whether to obtain the values from the specified frame or
        from all active frames. Possible values are SPECIFY and ALL. The default value is
        SPECIFY.
    """
    ...



from typing import Optional

from abqpy.decorators import abaqus_class_doc


@abaqus_class_doc
class MeshStats:
    """The MeshStats object is a query object for holding mesh statistics and is returned by
    the getMeshStats command. The object does not have any methods.

    .. note::
        This object can be accessed by::

            import mesh
    """

    #: An Int specifying the number of point elements.
    numPointElems: Optional[int] = None

    #: An Int specifying the number of line elements.
    numLineElems: Optional[int] = None

    #: An Int specifying the number of quadrilateral elements.
    numQuadElems: Optional[int] = None

    #: An Int specifying the number of triangular elements.
    numTriElems: Optional[int] = None

    #: An Int specifying the number of hexahedral elements.
    numHexElems: Optional[int] = None

    #: An Int specifying the number of wedge elements.
    numWedgeElems: Optional[int] = None

    #: An Int specifying the number of tetrahedral elements.
    numTetElems: Optional[int] = None

    #: An Int specifying the number of pyramid elements.
    numPyramidElems: Optional[int] = None

    #: An Int specifying the number of nodes.
    numNodes: Optional[int] = None

    #: An Int specifying the number of regions that contain a mesh.
    numMeshedRegions: Optional[int] = None



from typing import Optional

from abqpy.decorators import abaqus_class_doc, abaqus_method_doc

from .OdbAssembly import OdbAssembly
from .OdbInstance import OdbInstance
from .OdbMeshElement import OdbMeshElement
from .OdbMeshNode import OdbMeshNode
from .OdbPart import OdbPart
from .OdbSet import OdbSet
from .SectionPoint import SectionPoint
from ..UtilityAndView.abaqusConstants import DEFORMABLE_BODY, FACE_UNKNOWN, SymbolicConstant, THREE_D


@abaqus_class_doc
class HistoryPoint:
    """The HistoryPoint object specifies the point at which history data will be collected. The
    HistoryPoint object is a temporary object used as an argument to the HistoryRegion
    method.

    .. note::
        This object can be accessed by::

            import odbAccess
            session.odbs[name].steps[name].historyRegions[name].point
    """

    #: An Int specifying the integration point. This argument is used to define a history
    #: output position of INTEGRATION_POINT or ELEMENT_FACE_INTEGRATION_POINT. The default
    #: value is 0.
    ipNumber: int = 0

    #: A SymbolicConstant specifying the element face. This argument is used to define a
    #: history output position of ELEMENT_FACE or ELEMENT_FACE_INTEGRATION_POINT. Possible
    #: values are:
    #:
    #: - FACE_UNKOWN, specifying this value indicates that no value has been specified.
    #: - FACE1, specifying this value indicates that element face 1 has been specified.
    #: - FACE2, specifying this value indicates that element face 2 has been specified.
    #: - FACE3, specifying this value indicates that element face 3 has been specified.
    #: - FACE4, specifying this value indicates that element face 4 has been specified.
    #: - FACE5, specifying this value indicates that element face 5 has been specified.
    #: - FACE6, specifying this value indicates that element face 6 has been specified.
    #: - SIDE1, specifying this value indicates that element side 1 has been specified.
    #: - SIDE2, specifying this value indicates element side 2 has been specified.
    #: - END1, specifying this value indicates that element end 1 has been specified.
    #: - END2, specifying this value indicates that element end 2 has been specified.
    #: - END3, specifying this value indicates that element end 3 has been specified.
    #:
    #: The default value is FACE_UNKNOWN.
    face: SymbolicConstant = FACE_UNKNOWN

    #: A SymbolicConstant specifying the result position of the history point. Possible values
    #: are:
    #:
    #: - NODAL, specifying the values calculated at the nodes.
    #: - ELEMENT_NODAL, specifying the values obtained by extrapolating results calculated at
    #:   the integration points.
    #: - INTEGRATION_POINT, specifying the values calculated at the integration points.
    #: - ELEMENT_FACE, specifying the results obtained for surface variables such as cavity
    #:   radiation that are defined for the surface facets of an element.
    #: - ELEMENT_FACE_INTEGRATION_POINT, specifying the results obtained for surface variables
    #:   such as cavity radiation that are defined for the surface facets of an element when the
    #:   surface facets have integration points.
    #: - WHOLE_ELEMENT, specifying the results obtained for whole element variables.
    #: - WHOLE_REGION, specifying the results for an entire region of the model.
    #: - WHOLE_PART_INSTANCE, specifying the results for an entire part instance of the model.
    #: - WHOLE_MODEL, specifying the results for the entire model.
    position: Optional[SymbolicConstant] = None

    #: An OdbMeshElement object specifying the element for which the data are to be collected.
    element: OdbMeshElement = OdbMeshElement()

    #: A SectionPoint object.
    sectionPoint: Optional[SectionPoint] = None

    #: An OdbSet object specifying the region for which the data are to be collected.
    region: OdbSet = OdbSet("set", ())

    #: An OdbAssembly object specifying the assembly for which the data are to be collected.
    assembly: OdbAssembly = OdbAssembly()

    #: An OdbInstance object specifying the instance for which the data are to be collected.
    instance: OdbInstance = OdbInstance("instance", OdbPart("part", THREE_D, DEFORMABLE_BODY))

    #: An OdbMeshNode object specifying the node for which the data are to be collected.
    node: OdbMeshNode

    @abaqus_method_doc
    def __init__(self, node: OdbMeshNode):
        """This method creates a HistoryPoint object for a node.

        .. note::
            This function can be accessed by::

                odbAccess.HistoryPoint

        Parameters
        ----------
        node
            An OdbMeshNode object specifying the node for which the data are to be collected.

        Returns
        -------
        HistoryPoint
            A HistoryPoint object.
        """
        ...

    @abaqus_method_doc
    def __init__(
        self,
        element: OdbMeshElement,
        ipNumber: int = 0,
        sectionPoint: Optional[SectionPoint] = None,
        face: SymbolicConstant = FACE_UNKNOWN,
        node: Optional[OdbMeshNode] = None,
    ):
        """This method creates a HistoryPoint object for an element.

        .. note::
            This function can be accessed by::

                odbAccess.HistoryPoint

        Parameters
        ----------
        element
            An OdbMeshElement object specifying the element for which the data are to be collected.
        ipNumber
            An Int specifying the integration point. This argument is used to define a history
            output position of INTEGRATION_POINT or ELEMENT_FACE_INTEGRATION_POINT. The default
            value is 0.
        sectionPoint
            A SectionPoint object.
        face
            A SymbolicConstant specifying the element face. This argument is used to define a
            history output position of ELEMENT_FACE or ELEMENT_FACE_INTEGRATION_POINT. Possible
            values are:

            - FACE_UNKOWN, specifying this value indicates that no value has been specified.
            - FACE1, specifying this value indicates that element face 1 has been specified.
            - FACE2, specifying this value indicates that element face 2 has been specified.
            - FACE3, specifying this value indicates that element face 3 has been specified.
            - FACE4, specifying this value indicates that element face 4 has been specified.
            - FACE5, specifying this value indicates that element face 5 has been specified.
            - FACE6, specifying this value indicates that element face 6 has been specified.
            - SIDE1, specifying this value indicates that element side 1 has been specified.
            - SIDE2, specifying this value indicates element side 2 has been specified.
            - END1, specifying this value indicates that element end 1 has been specified.
            - END2, specifying this value indicates that element end 2 has been specified.
            - END3, specifying this value indicates that element end 3 has been specified.

            The default value is FACE_UNKNOWN.
        node
            An OdbMeshNode object specifying the node for which the data are to be collected.

        Returns
        -------
        HistoryPoint
            A HistoryPoint object.
        """
        ...

    @abaqus_method_doc
    def __init__(self, region: OdbSet):
        """This method creates a HistoryPoint object for a region.

        .. note::
            This function can be accessed by::

                odbAccess.HistoryPoint

        Parameters
        ----------
        region
            An OdbSet object specifying the region for which the data are to be collected.

        Returns
        -------
        HistoryPoint
            A HistoryPoint object.
        """
        ...

    @abaqus_method_doc
    def __init__(self, assembly: OdbAssembly):
        """This method creates a HistoryPoint object for the OdbAssembly object.

        .. note::
            This function can be accessed by::

                odbAccess.HistoryPoint

        Parameters
        ----------
        assembly
            An OdbAssembly object specifying the assembly for which the data are to be collected.

        Returns
        -------
        HistoryPoint
            A HistoryPoint object.
        """
        ...

    @abaqus_method_doc
    def __init__(self, instance: OdbInstance):
        """This method creates a HistoryPoint object for the OdbInstance object.

        .. note::
            This function can be accessed by::

                odbAccess.HistoryPoint

        Parameters
        ----------
        instance
            An OdbInstance object specifying the instance for which the data are to be collected.

        Returns
        -------
        HistoryPoint
            A HistoryPoint object.
        """
        ...

    def __init__(self, *args, **kwargs):
        ...
